==> pylibCZIrw-3.2.1.tar.gz: pylibCZIrw-3.2.1/libs/libCZIrw/CONTRIBUTING.md <==
# Introduction
Thank you for considering contributing to libczi.  

Following these guidelines helps to communicate that you respect the time of the developers managing and developing this open source project. In return, they should reciprocate that respect in addressing your issue, assessing changes, and helping you finalize your pull requests.  

libczi is an open source project and we love to receive contributions from our community — you! There are many ways to contribute, from writing tutorials or blog posts, improving the documentation, submitting bug reports and feature requests or writing code which can be incorporated into libczi itself.  

# Code of Conduct
[Be kind](/CODE_OF_CONDUCT.md)

# Reporting Issues
Depending on the nature of the bug/issue, the following guidelines apply:

## Security
You must never report security related issues, vulnerabilities or bugs including sensitive information to the bug/issue tracker, or elsewhere in public. Instead, please follow the guidelines set-up in [SECURITY.md](/SECURITY.md).

## Other Issues
Please revisit all previously created issues before creating a new issue.  
Choose from one of the provided templates and carefully fill out all required information.

# Suggesting a Feature
If you find yourself wishing for a feature or improvement that doesn't exist in libczi, you are probably not alone. There are bound to be others out there with similar needs. Many of the features that libczi has today have been added because our users saw the need. Open an issue on our issues list on GitHub which describes the feature you would like to see, why you need it, and how it should work.

# Creating a PR
We are always happy to receive code contributions from your side.  

For all contributions, please respect the following guidelines:
- Make sure to either sign the [Individual](./cla_individual.txt) or the [Corporate](./cla_corporate.txt) Contributor License Agreement (CLA) and send it to github.microscopy@zeiss.com.
- Always associate a PR with either an [issue](#other-issues) or a [feature](#suggesting-a-feature).  
- Each PR should implement ONE feature or bugfix. If you want to add or fix more than one thing, submit more than one PR.
- Do not commit changes to files that are irrelevant to your feature or bugfix.
- Be willing to accept criticism and work on improving your code.
- Be aware that the PR review process is not immediate, and is generally proportional to the size of the PR.

# Attribution
This template was inspired by https://github.com/nayafia/contributing-template.

==> pylibCZIrw-3.3.1.tar.gz: pylibCZIrw-3.3.1/libs/libCZIrw/CONTRIBUTING.md <==
# Introduction
Thank you for considering contributing to libCZI.  

Following these guidelines helps to communicate that you respect the time of the developers managing and developing this open source project. In return, they should reciprocate that respect in addressing your issue, assessing changes, and helping you finalize your pull requests.  

libCZI is an open source project and we love to receive contributions from our community — you! There are many ways to contribute, from writing tutorials or blog posts, improving the documentation, submitting bug reports and feature requests or writing code which can be incorporated into libCZI itself.  

No matter how you intend to participate in improving libCZI - please make sure to follow our [Code of Conduct](/CODE_OF_CONDUCT.md).

# Reporting Issues
Depending on the nature of the bug/issue, the following guidelines apply:

## Security
You must never report security related issues, vulnerabilities or bugs including sensitive information to the bug/issue tracker, or elsewhere in public. Instead, please follow the guidelines set-up in [SECURITY.md](/SECURITY.md).

## Other Issues
Please revisit all previously created issues before creating a new issue.  
Choose from one of the provided templates and carefully fill out all required information.

# Suggesting a Feature
If you find yourself wishing for a feature or improvement that doesn't exist in libCZI, you are probably not alone. There are bound to be others out there with similar needs. Many of the features that libCZI has today have been added because our users saw the need. Open an issue on our issues list on GitHub which describes the feature you would like to see, why you need it, and how it should work.

# Creating a PR
We are always happy to receive code contributions from your side.  

For all contributions, please respect the following guidelines:
- Make sure to either sign the [Individual](./cla_individual.txt) or the [Corporate](./cla_corporate.txt) Contributor License Agreement (CLA) and send it to github.microscopy@zeiss.com.
- Always associate a PR with either an [issue](#other-issues) or a [feature](#suggesting-a-feature).  
- Each PR should implement ONE feature or bugfix. If you want to add or fix more than one thing, submit more than one PR.
- Do not commit changes to files that are irrelevant to your feature or bugfix.
- Be willing to accept criticism and work on improving your code.
- Be aware that the PR review process is not immediate, and is generally proportional to the size of the PR.

# Attribution
This template was inspired by https://github.com/nayafia/contributing-template.
